==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/th/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'ผู้ใช้รายนี้สามารถเข้าระบบได้',
    'activated_disabled_help_text' => 'คุณไม่สามารถแก้ไขสถานะเปิดใช้งานสำหรับบัญชีของคุณเอง',
    'assets_user'       => 'ทรัพย์สินที่กำหนดให้ :name',
    'bulk_update_warn'	=> 'คุณกำลังแก้ไขคุณสมบัติของ: user_count users โปรดทราบว่าคุณไม่สามารถเปลี่ยนแอตทริบิวต์ผู้ใช้ของคุณเองโดยใช้แบบฟอร์มนี้และต้องแก้ไขผู้ใช้ของคุณเองเป็นรายบุคคล',
    'bulk_update_help'	=> 'ฟอร์มนี้ช่วยให้คุณสามารถอัปเดตผู้ใช้หลายรายพร้อมกัน กรอกข้อมูลในช่องที่คุณต้องการเปลี่ยนเท่านั้น ช่องใด ๆ ที่เว้นไว้จะไม่มีการเปลี่ยนแปลง',
    'current_assets'    => 'เนื้อหาปัจจุบันที่เช็คเอาท์ให้กับผู้ใช้รายนี้',
    'clone'             => 'โคลนผู้ใช้',
    'contact_user'      => 'ติดต่อ :name',
    'edit'              => 'แก้ไขผู้ใช้',
    'filetype_info'     => 'ประเภทของไฟล์ที่อนุญาตแล้ว มีดังนี้ png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar',
    'history_user'      => 'ประวัติของ :name',
	'info'				=> 'ข้อมูล',
    'restore_user'		=> 'คลิกที่นี่เพื่อเรียกคืน',
    'last_login'        => 'เข้าสู่ระบบล่าสุด',
    'ldap_config_text'  => 'คุณสามารถตั้งค่าการกำหนดค่า LDAP ได้ Admin> การตั้งค่า สถานที่ที่เลือก (เลือกได้) จะถูกตั้งค่าสำหรับผู้ใช้ที่นำเข้าทั้งหมด',
    'print_assigned'    => 'พิมพ์รายการทั้งหมดที่ได้รับมอบหมาย',
    'software_user'     => 'ซอฟต์แวร์ที่กำหนดให้ :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'ดูผู้ใช้ :name',
    'usercsv'           => 'ไฟล์ CSV',
    'two_factor_admin_optin_help' => 'การตั้งค่าผู้ดูแลระบบปัจจุบันช่วยให้สามารถใช้การตรวจสอบสิทธิ์แบบสองปัจจัยได้อย่างมีประสิทธิภาพ',
    'two_factor_enrolled' => 'อุปกรณ์ 2FA ที่ลงทะเบียนแล้ว',
    'two_factor_active'   => '2FA Active',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/th/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'ผู้ใช้รายนี้สามารถเข้าระบบได้',
    'activated_disabled_help_text' => 'คุณไม่สามารถแก้ไขสถานะเปิดใช้งานสำหรับบัญชีของคุณเอง',
    'assets_user'       => 'ทรัพย์สินที่กำหนดให้ :name',
    'bulk_update_warn'	=> 'คุณกำลังแก้ไขคุณสมบัติของ: user_count users โปรดทราบว่าคุณไม่สามารถเปลี่ยนแอตทริบิวต์ผู้ใช้ของคุณเองโดยใช้แบบฟอร์มนี้และต้องแก้ไขผู้ใช้ของคุณเองเป็นรายบุคคล',
    'bulk_update_help'	=> 'ฟอร์มนี้ช่วยให้คุณสามารถอัปเดตผู้ใช้หลายรายพร้อมกัน กรอกข้อมูลในช่องที่คุณต้องการเปลี่ยนเท่านั้น ช่องใด ๆ ที่เว้นไว้จะไม่มีการเปลี่ยนแปลง',
    'current_assets'    => 'เนื้อหาปัจจุบันที่เช็คเอาท์ให้กับผู้ใช้รายนี้',
    'clone'             => 'โคลนผู้ใช้',
    'contact_user'      => 'ติดต่อ :name',
    'edit'              => 'แก้ไขผู้ใช้',
    'filetype_info'     => 'ประเภทของไฟล์ที่อนุญาตแล้ว มีดังนี้ png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar',
    'history_user'      => 'ประวัติของ :name',
    'info'				=> 'ข้อมูล',
    'restore_user'		=> 'คลิกที่นี่เพื่อเรียกคืน',
    'last_login'        => 'เข้าสู่ระบบล่าสุด',
    'ldap_config_text'  => 'คุณสามารถตั้งค่าการกำหนดค่า LDAP ได้ Admin> การตั้งค่า สถานที่ที่เลือก (เลือกได้) จะถูกตั้งค่าสำหรับผู้ใช้ที่นำเข้าทั้งหมด',
    'print_assigned'    => 'พิมพ์รายการทั้งหมดที่ได้รับมอบหมาย',
    'software_user'     => 'ซอฟต์แวร์ที่กำหนดให้ :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'ดูผู้ใช้ :name',
    'usercsv'           => 'ไฟล์ CSV',
    'two_factor_admin_optin_help' => 'การตั้งค่าผู้ดูแลระบบปัจจุบันช่วยให้สามารถใช้การตรวจสอบสิทธิ์แบบสองปัจจัยได้อย่างมีประสิทธิภาพ',
    'two_factor_enrolled' => 'อุปกรณ์ 2FA ที่ลงทะเบียนแล้ว',
    'two_factor_active'   => '2FA Active',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
